FieldValueData<T> class final

Represents a FieldValue that can be stored in Firestore.

This class encapsulates a Firestore FieldValue, allowing its use in Firestore operations.

Inheritance

Constructors

FieldValueData(FieldValue fieldValue)
Creates a FieldValueData.
const

Properties

actualValue → T
Retrieves the data, whether as a FieldValue or actual value.
no setterinherited
fieldValue → FieldValue
Retrieves the FieldValue representation of the data.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → dynamic
Creates a FirestoreData from a FieldValue or an actual value.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited